WRITESONIC_BASE_URL = 'https://api.writesonic.com'
CHATSONIC_URL_PATH = '/v2/business/content/chatsonic'
WRITESONIC_ENGINE_PREMIUM = 'premium'
WRITESONIC_ENGINE_SUPERIUM = 'superium'
WRITESONIC_ENGINES = (WRITESONIC_ENGINE_PREMIUM, WRITESONIC_ENGINE_SUPERIUM)
WRITESONIC_LANGUAGE_ENGLISH = 'en'
WRITESONIC_LANGUAGE_CHINESE = 'zh'
WRITESONIC_LANGUAGES = (WRITESONIC_LANGUAGE_ENGLISH, WRITESONIC_LANGUAGE_CHINESE)
